Module expr

Module expr 

The type definitions for the computation format of the surreaql executor.

Re-exports

pub use self::access_type::AccessType;
pub use self::access_type::JwtAccess;
pub use self::access_type::RecordAccess;
pub use self::algorithm::Algorithm;
pub use self::base::Base;
pub use self::block::Block;
pub use self::bytesize::Bytesize;
pub use self::changefeed::ChangeFeed;
pub use self::closure::ClosureExpr;
pub use self::cond::Cond;
pub use self::constant::Constant;
pub use self::data::Data;
pub use self::dir::Dir;
pub use self::error::Error;
pub use self::explain::Explain;
pub use self::expression::ExplainFormat;
pub use self::expression::Expr;
pub use self::fetch::Fetch;
pub use self::fetch::Fetchs;
pub use self::field::Field;
pub use self::field::Fields;
pub use self::filter::Filter;
pub use self::function::Function;
pub use self::function::FunctionCall;
pub use self::group::Group;
pub use self::group::Groups;
pub use self::idiom::Idiom;
pub use self::kind::Kind;
pub use self::kind::KindLiteral;
pub use self::limit::Limit;
pub use self::literal::Literal;
pub use self::literal::ObjectEntry;
pub use self::lookup::Lookup;
pub use self::match_plan::MatchPlan;
pub use self::mock::Mock;
pub use self::model::Model;
pub use self::module::ModuleExecutable;
pub use self::module::SiloExecutable;
pub use self::module::SurrealismExecutable;
pub use self::operation::Operation;
pub use self::operator::AssignOperator;
pub use self::operator::BinaryOperator;
pub use self::operator::PostfixOperator;
pub use self::operator::PrefixOperator;
pub use self::order::Order;
pub use self::output::Output;
pub use self::param::Param;
pub use self::part::Part;
pub use self::plan::LogicalPlan;
pub use self::plan::TopLevelExpr;
pub use self::record_id::RecordIdKeyGen;
pub use self::record_id::RecordIdKeyLit;
pub use self::record_id::RecordIdKeyRangeLit;
pub use self::record_id::RecordIdLit;
pub use self::script::Script;
pub use self::split::Split;
pub use self::split::Splits;
pub use self::start::Start;
pub use self::statements::DefineAnalyzerStatement;
pub use self::statements::SelectStatement;
pub use self::statements::SleepStatement;
pub use self::tokenizer::SegmentLanguage;
pub use self::tokenizer::Tokenizer;
pub use self::view::View;
pub use self::with::With;

Modules

access
access_type
algorithm
base
block
bytesize
changefeed
closure
computed_deps
Computed field dependency extraction.
cond
constant
convert
data
decimal
Decimal functionality and extension traits.
dir
error
Failures raised by the value algebra.
explain
expression
fetch
field
filter
function
function_facts
Local, derivable facts about an expression’s ability to modify data.
graphql_config
GraphQL exposure configuration.
group
idiom
index_kind
The parsed index-parameter clause of a DEFINE INDEX statement.
kind
language
limit
literal
lookup
match_plan
The declarative IR for GQL v2 MATCH queries.
method
The static mirror of the builtin method dispatch tables.
mock
model
module
mutation
Whether a stored expression can modify data anywhere in its own tree.
operation
operator
order
output
param
part
paths
permission
Permission guards attached to schema objects.
plan
record_id
reference
script
split
start
statements
table_type
The kind of a table: schemafull document, relation, or any.
tokenizer
user
variables
view
visit
with

Enums

ControlFlow
An enum carrying control flow information.

Traits

ControlFlowExt
Extension trait for wrapping errors with context and converting them into ControlFlow.

Type Aliases

FlowResult
Result of functions which can impact the controlflow of query execution.