pub enum AccessType {
Record(Box<RecordAccess>),
Jwt(JwtAccess),
Bearer(BearerAccess),
}Expand description
The type of access methods available
Variants
Implementations
Sourceimpl AccessType
impl AccessType
Sourcepub fn can_issue_grants(&self) -> bool
pub fn can_issue_grants(&self) -> bool
Returns whether or not the access method can issue non-token grants In this context, token refers exclusively to JWT
Sourcepub fn can_issue_tokens(&self) -> bool
pub fn can_issue_tokens(&self) -> bool
Returns whether or not the access method can issue tokens In this context, tokens refers exclusively to JWT