Fetchs

Struct Fetchs 

pub struct Fetchs(/* private fields */);
A list of fetches to be applied to the result of a query.

Fetches are applied to the result of a query in the order they are specified. For this reason, the list of fetches is always sorted to ensure that parent fetches are applied before child fetches.

For example: FETCH a.b, a is sorted to FETCH a, a.b. FETCH a.b, a.b.c, d, a, b is sorted to FETCH a, a.b, a.b.c, b, d.

This prevents confusing behaviour like FETCH a.b, a only returning a because a.b gets clobbered by a.

Implementations

Source

impl Fetchs

pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]

Field names at the given wire revision in declaration order. Returns an empty slice if the revision is unknown. Generated by the revisioned derive.

Source

impl Fetchs

pub const REVISION: u16 = 1u16

The revision number of this type, as declared via #[revisioned(revision = N)].

Source

impl Fetchs

pub fn new(fetches: Vec<Fetch>) -> Self

pub fn read_only(&self) -> bool

Whether evaluating every fetch target can be done on a read-only transaction.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn iter(&self) -> impl Iterator<Item = &Fetch>

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Fetch>