pub enum Fields {
Value(Box<Selector>),
Select(Vec<Field>),
}Expand description
The foo,bar,* part of statements like SELECT foo,bar.* FROM faz.
Variants
Value(Box<Selector>)
Fields had the VALUE clause and should only return the given selector
This variant should not contain Field::All TODO: Encode the above variant into the type.
Select(Vec<Field>)
Normal fields where an object with the selected fields is expected
Implementations
Sourceimpl Fields
impl Fields
Sourcepub fn walk_revisioned_variant_name(
wire_revision: u16,
discriminant: u32,
) -> Option<&'static str>
pub fn walk_revisioned_variant_name( wire_revision: u16, discriminant: u32, ) -> Option<&'static str>
Resolve a wire discriminant at wire_revision to the variant
identifier at that revision. Returns None if no such variant
exists at that revision.
Generated by the revisioned derive.
Sourcepub fn walk_revisioned_variant_table(
wire_revision: u16,
) -> &'static [(&'static str, u32)]
pub fn walk_revisioned_variant_table( wire_revision: u16, ) -> &'static [(&'static str, u32)]
Variant name + discriminant pairs at wire_revision. Returns
an empty slice if the revision is unknown. Generated by the
revisioned derive.
Sourceimpl Fields
impl Fields
Sourcepub fn read_only(&self) -> bool
pub fn read_only(&self) -> bool
Returns true if computing this value can be done on a read only transaction.
Sourcepub fn has_all_selection(&self) -> bool
pub fn has_all_selection(&self) -> bool
Check to see if this field is a * projection
Sourcepub fn iter_non_all_fields(&self) -> FieldsIter<'_> ⓘ
pub fn iter_non_all_fields(&self) -> FieldsIter<'_> ⓘ
Returns an iterator which returns all fields which are not Field::All.
Sourcepub fn is_count_all_only(&self) -> bool
pub fn is_count_all_only(&self) -> bool
Check if the fields are only about counting