pub struct GraphQLConfigWalker<'r, R: BorrowedReader + 'r> { /* private fields */ }Expand description
Walker for a revisioned struct. Generated by #[revisioned(...)].
Implementations
Sourceimpl<'r, R: BorrowedReader + 'r> GraphQLConfigWalker<'r, R>
impl<'r, R: BorrowedReader + 'r> GraphQLConfigWalker<'r, R>
Sourcepub fn decode_tables(&mut self) -> Result<GraphQLTablesConfig, Error>
pub fn decode_tables(&mut self) -> Result<GraphQLTablesConfig, Error>
Decode this field, advancing the walker.
For IndexedBorrowed walkers (optimised + indexed_struct),
the offset table is consulted to jump directly to this field’s
bytes in O(1) — reading any field is independent of how many
fields precede it on the wire.
Sourcepub fn skip_tables(&mut self) -> Result<(), Error>
pub fn skip_tables(&mut self) -> Result<(), Error>
Skip this field, advancing the walker.
Free under IndexedBorrowed mode (the offset table already
lets decode_<field> jump directly to any field; “skip”
just bumps the position counter).
Sourcepub fn walk_tables(
&mut self,
) -> Result<<GraphQLTablesConfig as WalkRevisioned>::Walker<'_, R>, Error>
pub fn walk_tables( &mut self, ) -> Result<<GraphQLTablesConfig as WalkRevisioned>::Walker<'_, R>, Error>
Walk into this field. For fields tagged
#[revision(indexed_map)] / #[revision(indexed_seq)],
returns an IndexedMapView / IndexedSeqView
the caller can borrow an IndexedMapWalker /
IndexedSeqWalker from. For all other fields, returns the
inner type’s WalkRevisioned::Walker as usual (borrowing
the parent walker for the duration of the sub-walk).
ConvertedOwned walkers (older-rev convert_fn types) return
revision::Error::Conversion for the legacy path; the
indexed branches re-serialise from the owned value.
Sourcepub fn into_walk_tables(
self,
) -> Result<<GraphQLTablesConfig as WalkRevisioned>::Walker<'r, R>, Error>
pub fn into_walk_tables( self, ) -> Result<<GraphQLTablesConfig as WalkRevisioned>::Walker<'r, R>, Error>
Walk into this field, consuming the parent walker. See
[Self::#walk_name] for shape details.
Sourcepub fn into_tables_bytes(self) -> Result<Cow<'r, [u8]>, Error>
pub fn into_tables_bytes(self) -> Result<Cow<'r, [u8]>, Error>
Consume this walker and return the field’s raw wire bytes
as Cow<'r, [u8]>, without decoding the inner type. Lets
the caller construct a child walker themselves via
T::walk_revisioned(&mut bytes). Borrowed from the source
buffer for IndexedBorrowed / Wire walkers; allocated on
the rare ConvertedOwned (cross-rev convert_fn) path.
Sourcepub fn decode_functions(&mut self) -> Result<GraphQLFunctionsConfig, Error>
pub fn decode_functions(&mut self) -> Result<GraphQLFunctionsConfig, Error>
Decode this field, advancing the walker.
For IndexedBorrowed walkers (optimised + indexed_struct),
the offset table is consulted to jump directly to this field’s
bytes in O(1) — reading any field is independent of how many
fields precede it on the wire.
Sourcepub fn skip_functions(&mut self) -> Result<(), Error>
pub fn skip_functions(&mut self) -> Result<(), Error>
Skip this field, advancing the walker.
Free under IndexedBorrowed mode (the offset table already
lets decode_<field> jump directly to any field; “skip”
just bumps the position counter).
Sourcepub fn walk_functions(
&mut self,
) -> Result<<GraphQLFunctionsConfig as WalkRevisioned>::Walker<'_, R>, Error>
pub fn walk_functions( &mut self, ) -> Result<<GraphQLFunctionsConfig as WalkRevisioned>::Walker<'_, R>, Error>
Walk into this field. For fields tagged
#[revision(indexed_map)] / #[revision(indexed_seq)],
returns an IndexedMapView / IndexedSeqView
the caller can borrow an IndexedMapWalker /
IndexedSeqWalker from. For all other fields, returns the
inner type’s WalkRevisioned::Walker as usual (borrowing
the parent walker for the duration of the sub-walk).
ConvertedOwned walkers (older-rev convert_fn types) return
revision::Error::Conversion for the legacy path; the
indexed branches re-serialise from the owned value.
Sourcepub fn into_walk_functions(
self,
) -> Result<<GraphQLFunctionsConfig as WalkRevisioned>::Walker<'r, R>, Error>
pub fn into_walk_functions( self, ) -> Result<<GraphQLFunctionsConfig as WalkRevisioned>::Walker<'r, R>, Error>
Walk into this field, consuming the parent walker. See
[Self::#walk_name] for shape details.
Sourcepub fn into_functions_bytes(self) -> Result<Cow<'r, [u8]>, Error>
pub fn into_functions_bytes(self) -> Result<Cow<'r, [u8]>, Error>
Consume this walker and return the field’s raw wire bytes
as Cow<'r, [u8]>, without decoding the inner type. Lets
the caller construct a child walker themselves via
T::walk_revisioned(&mut bytes). Borrowed from the source
buffer for IndexedBorrowed / Wire walkers; allocated on
the rare ConvertedOwned (cross-rev convert_fn) path.
Sourcepub fn decode_depth_limit(&mut self) -> Result<Option<u32>, Error>
pub fn decode_depth_limit(&mut self) -> Result<Option<u32>, Error>
Decode this field, advancing the walker.
For IndexedBorrowed walkers (optimised + indexed_struct),
the offset table is consulted to jump directly to this field’s
bytes in O(1) — reading any field is independent of how many
fields precede it on the wire.
Sourcepub fn skip_depth_limit(&mut self) -> Result<(), Error>
pub fn skip_depth_limit(&mut self) -> Result<(), Error>
Skip this field, advancing the walker.
Free under IndexedBorrowed mode (the offset table already
lets decode_<field> jump directly to any field; “skip”
just bumps the position counter).
Sourcepub fn walk_depth_limit(
&mut self,
) -> Result<<Option<u32> as WalkRevisioned>::Walker<'_, R>, Error>
pub fn walk_depth_limit( &mut self, ) -> Result<<Option<u32> as WalkRevisioned>::Walker<'_, R>, Error>
Walk into this field. For fields tagged
#[revision(indexed_map)] / #[revision(indexed_seq)],
returns an IndexedMapView / IndexedSeqView
the caller can borrow an IndexedMapWalker /
IndexedSeqWalker from. For all other fields, returns the
inner type’s WalkRevisioned::Walker as usual (borrowing
the parent walker for the duration of the sub-walk).
ConvertedOwned walkers (older-rev convert_fn types) return
revision::Error::Conversion for the legacy path; the
indexed branches re-serialise from the owned value.
Sourcepub fn into_walk_depth_limit(
self,
) -> Result<<Option<u32> as WalkRevisioned>::Walker<'r, R>, Error>
pub fn into_walk_depth_limit( self, ) -> Result<<Option<u32> as WalkRevisioned>::Walker<'r, R>, Error>
Walk into this field, consuming the parent walker. See
[Self::#walk_name] for shape details.
Sourcepub fn into_depth_limit_bytes(self) -> Result<Cow<'r, [u8]>, Error>
pub fn into_depth_limit_bytes(self) -> Result<Cow<'r, [u8]>, Error>
Consume this walker and return the field’s raw wire bytes
as Cow<'r, [u8]>, without decoding the inner type. Lets
the caller construct a child walker themselves via
T::walk_revisioned(&mut bytes). Borrowed from the source
buffer for IndexedBorrowed / Wire walkers; allocated on
the rare ConvertedOwned (cross-rev convert_fn) path.
Sourcepub fn decode_complexity_limit(&mut self) -> Result<Option<u32>, Error>
pub fn decode_complexity_limit(&mut self) -> Result<Option<u32>, Error>
Decode this field, advancing the walker.
For IndexedBorrowed walkers (optimised + indexed_struct),
the offset table is consulted to jump directly to this field’s
bytes in O(1) — reading any field is independent of how many
fields precede it on the wire.
Sourcepub fn skip_complexity_limit(&mut self) -> Result<(), Error>
pub fn skip_complexity_limit(&mut self) -> Result<(), Error>
Skip this field, advancing the walker.
Free under IndexedBorrowed mode (the offset table already
lets decode_<field> jump directly to any field; “skip”
just bumps the position counter).
Sourcepub fn walk_complexity_limit(
&mut self,
) -> Result<<Option<u32> as WalkRevisioned>::Walker<'_, R>, Error>
pub fn walk_complexity_limit( &mut self, ) -> Result<<Option<u32> as WalkRevisioned>::Walker<'_, R>, Error>
Walk into this field. For fields tagged
#[revision(indexed_map)] / #[revision(indexed_seq)],
returns an IndexedMapView / IndexedSeqView
the caller can borrow an IndexedMapWalker /
IndexedSeqWalker from. For all other fields, returns the
inner type’s WalkRevisioned::Walker as usual (borrowing
the parent walker for the duration of the sub-walk).
ConvertedOwned walkers (older-rev convert_fn types) return
revision::Error::Conversion for the legacy path; the
indexed branches re-serialise from the owned value.
Sourcepub fn into_walk_complexity_limit(
self,
) -> Result<<Option<u32> as WalkRevisioned>::Walker<'r, R>, Error>
pub fn into_walk_complexity_limit( self, ) -> Result<<Option<u32> as WalkRevisioned>::Walker<'r, R>, Error>
Walk into this field, consuming the parent walker. See
[Self::#walk_name] for shape details.
Sourcepub fn into_complexity_limit_bytes(self) -> Result<Cow<'r, [u8]>, Error>
pub fn into_complexity_limit_bytes(self) -> Result<Cow<'r, [u8]>, Error>
Consume this walker and return the field’s raw wire bytes
as Cow<'r, [u8]>, without decoding the inner type. Lets
the caller construct a child walker themselves via
T::walk_revisioned(&mut bytes). Borrowed from the source
buffer for IndexedBorrowed / Wire walkers; allocated on
the rare ConvertedOwned (cross-rev convert_fn) path.
Sourcepub fn decode_introspection(
&mut self,
) -> Result<GraphQLIntrospectionConfig, Error>
pub fn decode_introspection( &mut self, ) -> Result<GraphQLIntrospectionConfig, Error>
Decode this field, advancing the walker.
For IndexedBorrowed walkers (optimised + indexed_struct),
the offset table is consulted to jump directly to this field’s
bytes in O(1) — reading any field is independent of how many
fields precede it on the wire.
Sourcepub fn skip_introspection(&mut self) -> Result<(), Error>
pub fn skip_introspection(&mut self) -> Result<(), Error>
Skip this field, advancing the walker.
Free under IndexedBorrowed mode (the offset table already
lets decode_<field> jump directly to any field; “skip”
just bumps the position counter).
Sourcepub fn walk_introspection(
&mut self,
) -> Result<<GraphQLIntrospectionConfig as WalkRevisioned>::Walker<'_, R>, Error>
pub fn walk_introspection( &mut self, ) -> Result<<GraphQLIntrospectionConfig as WalkRevisioned>::Walker<'_, R>, Error>
Walk into this field. For fields tagged
#[revision(indexed_map)] / #[revision(indexed_seq)],
returns an IndexedMapView / IndexedSeqView
the caller can borrow an IndexedMapWalker /
IndexedSeqWalker from. For all other fields, returns the
inner type’s WalkRevisioned::Walker as usual (borrowing
the parent walker for the duration of the sub-walk).
ConvertedOwned walkers (older-rev convert_fn types) return
revision::Error::Conversion for the legacy path; the
indexed branches re-serialise from the owned value.
Sourcepub fn into_walk_introspection(
self,
) -> Result<<GraphQLIntrospectionConfig as WalkRevisioned>::Walker<'r, R>, Error>
pub fn into_walk_introspection( self, ) -> Result<<GraphQLIntrospectionConfig as WalkRevisioned>::Walker<'r, R>, Error>
Walk into this field, consuming the parent walker. See
[Self::#walk_name] for shape details.
Sourcepub fn into_introspection_bytes(self) -> Result<Cow<'r, [u8]>, Error>
pub fn into_introspection_bytes(self) -> Result<Cow<'r, [u8]>, Error>
Consume this walker and return the field’s raw wire bytes
as Cow<'r, [u8]>, without decoding the inner type. Lets
the caller construct a child walker themselves via
T::walk_revisioned(&mut bytes). Borrowed from the source
buffer for IndexedBorrowed / Wire walkers; allocated on
the rare ConvertedOwned (cross-rev convert_fn) path.