GeometryKindWalker

Struct GeometryKindWalker 

pub struct GeometryKindWalker<'r, R: BorrowedReader + 'r> { /* private fields */ }
Walker for a revisioned enum. Generated by #[revisioned(...)].

Implementations

Source

impl<'r, R: BorrowedReader + 'r> GeometryKindWalker<'r, R>

pub fn revision(&self) -> u16

Wire revision of the encoded value being walked.

pub fn discriminant(&self) -> u32

Variant discriminant on the wire (for Wire) or on the re-encoded current-rev bytes (for the borrowed / owned arms). Use walk_revisioned_variant_name to map this to a variant identifier.

pub fn is_point(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_point(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_point(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.

pub fn is_line(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_line(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_line(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.

pub fn is_polygon(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_polygon(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_polygon(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.

pub fn is_multi_point(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_multi_point(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_multi_point(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.

pub fn is_multi_line(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_multi_line(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_multi_line(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.

pub fn is_multi_polygon(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_multi_polygon(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_multi_polygon(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.

pub fn is_collection(&self) -> bool

Returns true if the wire’s discriminant identifies this variant at the wire revision (or, for borrowed / owned walkers, on the current-rev bytes).

pub fn into_collection(self) -> Result<(), Error>

Verify the wire encoding identifies the unit variant #variant_ident and return ().

pub fn decode_collection(self) -> Result<(), Error>

Decode the unit variant — same as into_<variant> for unit variants, kept for API symmetry.