Skip to main content Module paths Copy item path Source AC Access level string on the frozen-context session object.
Accessible via the session::ac() function or the $session.ac parameter. DB Active database name on the frozen-context session object.
Accessible via the session::db() function or the $session.db parameter. ID Single-field path for "id": record primary key when picking from a value, and the
authenticated session user id (UUID) on the frozen-context session object. IN Incoming endpoint in field on graph edges (-> / RELATE semantics). IP Client IP address stored on the frozen-context session object (session() / batch metadata).
Accessible via the session::ip() function or the $session.ip parameter. NS Active namespace name on the frozen-context session object.
Accessible via the session::ns() function or the $session.ns parameter. OR Request origin string on the frozen-context session object.
Accessible via the session::origin() function or the $session.or parameter. OUT Outgoing endpoint out field on graph edges (-> / RELATE semantics). RD Auth-related payload on the frozen-context session object.
Accessible via the session::rd() function or the $session.rd parameter. TK Auth token material on the frozen-context session object.
Accessible via the session::token() function or the $session.tk parameter.