DefineAccessStatement

Struct DefineAccessStatement 

pub struct DefineAccessStatement {
    pub kind: DefineKind,
    pub name: Expr,
    pub base: Base,
    pub access_type: AccessType,
    pub authenticate: Option<Expr>,
    pub context: Option<Expr>,
    pub duration: AccessDuration,
    pub comment: Expr,
}

Fields

kind: DefineKindname: Exprbase: Baseaccess_type: AccessTypeauthenticate: Option<Expr>context: Option<Expr>duration: AccessDurationcomment: Expr

Implementations

Source

impl DefineAccessStatement

pub fn random_key() -> String

Generate a random key to be used to sign session tokens This key will be used to sign tokens issued with this access method This value is used by default in every access method other than JWT

Source

impl DefineAccessStatement

pub fn redact(self) -> Self

Remove information from the access definition which should not be displayed.