pub struct RelateStatement {
pub only: bool,
pub or_update: bool,
pub through: Expr,
pub from: Expr,
pub to: Expr,
pub data: Option<Data>,
pub output: Option<Output>,
pub timeout: Expr,
}Fields
only: boolor_update: boolWhen true, update an existing edge record with the same explicit id.
through: ExprThe expression resulting in the table through which we create a relation
from: ExprThe expression the relation is from
to: ExprThe expression the relation targets.
data: Option<Data>The data associated with the relation being created
output: Option<Output>What the result of the statement should resemble (i.e. Diff or no result etc).
timeout: ExprThe timeout for the statement