Geometry

Enum Geometry 

pub enum Geometry {
    Point(Point<f64>),
    Line(LineString<f64>),
    Polygon(Polygon<f64>),
    MultiPoint(MultiPoint<f64>),
    MultiLine(MultiLineString<f64>),
    MultiPolygon(MultiPolygon<f64>),
    Collection(Vec<Geometry>),
}

Variants



Point(Point<f64>)



Line(LineString<f64>)



Polygon(Polygon<f64>)



MultiPoint(MultiPoint<f64>)



MultiLine(MultiLineString<f64>)



MultiPolygon(MultiPolygon<f64>)



Collection(Vec<Geometry>)

Implementations

Source

impl Geometry

pub fn walk_revisioned_variant_name( wire_revision: u16, discriminant: u32, ) -> Option<&'static str>

Resolve a wire discriminant at wire_revision to the variant identifier at that revision. Returns None if no such variant exists at that revision.

Generated by the revisioned derive.

pub fn walk_revisioned_variant_table( wire_revision: u16, ) -> &'static [(&'static str, u32)]

Variant name + discriminant pairs at wire_revision. Returns an empty slice if the revision is unknown. Generated by the revisioned derive.

Source

impl Geometry

pub const REVISION: u16 = 1u16

The revision number of this type, as declared via #[revisioned(revision = N)].

Source

impl Geometry

pub fn is_geometry(&self) -> bool

Check if this is not a Collection

pub fn is_collection(&self) -> bool

Check if this is a Collection

pub fn is_valid(&self) -> bool

Check if this has valid latitude and longitude points:

  • -90 <= lat <= 90
  • -180 <= lng <= 180
pub fn as_type(&self) -> &'static str

Get the type of this Geometry as text

pub fn as_coordinates(&self) -> Value

Get the raw coordinates of this Geometry as an Array

pub fn as_object(&self) -> Object

Get the GeoJSON object representation for this geometry

pub fn try_from_object(object: &Object) -> Option<Geometry>

pub fn array_to_multipolygon(v: &Value) -> Option<MultiPolygon<f64>>

Converts a surreal value to a MultiPolygon if the array matches to a MultiPolygon.

pub fn array_to_multiline(v: &Value) -> Option<MultiLineString<f64>>

Converts a surreal value to a MultiLine if the array matches to a MultiLine.

pub fn array_to_multipoint(v: &Value) -> Option<MultiPoint<f64>>

Converts a surreal value to a MultiPoint if the array matches to a MultiPoint.

pub fn array_to_polygon(v: &Value) -> Option<Polygon<f64>>

Converts a surreal value to a Polygon if the array matches to a Polygon.

pub fn array_to_line(v: &Value) -> Option<LineString<f64>>

Converts a surreal value to a LineString if the array matches to a LineString.

pub fn array_to_point(v: &Value) -> Option<Point<f64>>

Converts a surreal value to a Point if the array matches to a point.

pub fn contains(&self, other: &Self) -> bool

pub fn intersects(&self, other: &Self) -> bool