Range

Struct Range 

pub struct Range {
    pub start: Bound<Value>,
    pub end: Bound<Value>,
}
A range of surrealql values,

Can be any kind of values, “a”..1 is allowed.

Fields

start: Bound<Value>end: Bound<Value>

Implementations

Source

impl Range

pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]

Field names at the given wire revision in declaration order. Returns an empty slice if the revision is unknown. Generated by the revisioned derive.

Source

impl Range

pub const REVISION: u16 = 1u16

The revision number of this type, as declared via #[revisioned(revision = N)].

Source

impl Range

pub const fn unbounded() -> Self

returns a range with no bounds.

pub fn is_empty(&self) -> bool

Returns if the range cannot contain a value.

pub fn intersect(self, other: Self) -> Self

Returns the intersection of two ranges.

Source

impl Range