pub struct TypedRange<T> {
pub start: Bound<T>,
pub end: Bound<T>,
}Expand description
A range of a specific type, can be converted back into a general range and coerced from a general range.
Fields
start: Bound<T>end: Bound<T>Implementations
Sourceimpl<T> TypedRange<T>where
T: Clone,
impl<T> TypedRange<T>where
T: Clone,
pub fn from_range<R>(r: R) -> TypedRange<T>where
R: RangeBounds<T>,