IntegerRangeExt

Trait IntegerRangeExt 

pub trait IntegerRangeExt {
    // Required method
    fn cast_to_array(self) -> Array;
}
TypedRange<i64> lives in surrealdb-common, below the value layer, so the conversion into an Array cannot be an inherent method on it.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors