pub struct Selector {
pub expr: Expr,
pub alias: Option<Idiom>,
}Fields
expr: Expralias: Option<Idiom>The quality in SELECT rating AS quality FROM ...
Implementations
Sourceimpl Selector
impl Selector
Sourcepub fn walk_revisioned_field_names(
wire_revision: u16,
) -> &'static [&'static str]
pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]
Field names at the given wire revision in declaration order.
Returns an empty slice if the revision is unknown. Generated
by the revisioned derive.