pub struct GraphQLConfig {
pub tables: GraphQLTablesConfig,
pub functions: GraphQLFunctionsConfig,
pub depth_limit: Option<u32>,
pub complexity_limit: Option<u32>,
pub introspection: GraphQLIntrospectionConfig,
}Fields
tables: GraphQLTablesConfigfunctions: GraphQLFunctionsConfigdepth_limit: Option<u32>Maximum query nesting depth. None means no limit.
complexity_limit: Option<u32>Maximum query complexity (total number of fields). None means no limit.
introspection: GraphQLIntrospectionConfigControls whether GraphQL schema introspection is enabled.
Defaults to Auto (introspection enabled).
Implementations
Sourceimpl GraphQLConfig
impl GraphQLConfig
Sourcepub fn walk_revisioned_field_names(
wire_revision: u16,
) -> &'static [&'static str]
pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]
Field names at the given wire revision in declaration order.
Returns an empty slice if the revision is unknown. Generated
by the revisioned derive.