pub struct DefineAccessStatement {
pub kind: DefineKind,
pub name: Expr,
pub base: Base,
pub access_type: AccessType,
pub authenticate: Option<Expr>,
pub context: Option<Expr>,
pub duration: AccessDuration,
pub comment: Expr,
}Fields
kind: DefineKindname: Exprbase: Baseaccess_type: AccessTypeauthenticate: Option<Expr>context: Option<Expr>duration: AccessDurationcomment: ExprImplementations
Sourceimpl DefineAccessStatement
impl DefineAccessStatement
Sourcepub fn random_key() -> String
pub fn random_key() -> String
Generate a random key to be used to sign session tokens This key will be used to sign tokens issued with this access method This value is used by default in every access method other than JWT