pub struct Datetime(pub DateTime<Utc>);Tuple Fields
0: DateTime<Utc>Implementations
Sourceimpl Datetime
impl Datetime
Sourcepub fn walk_revisioned_field_names(
wire_revision: u16,
) -> &'static [&'static str]
pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]
Field names at the given wire revision in declaration order.
Returns an empty slice if the revision is unknown. Generated
by the revisioned derive.
Sourceimpl Datetime
impl Datetime
Sourcepub fn to_version_stamp(self, ts_impl: &dyn TimeStampImpl) -> Result<u64>
pub fn to_version_stamp(self, ts_impl: &dyn TimeStampImpl) -> Result<u64>
Convert the datetime to a version stamp using the datastore’s timestamp implementation.
Methods from Deref<Target = DateTime<Utc>>
Sourcepub fn date(&self) -> Date<Tz>
👎Deprecated since 0.4.23: Use date_naive() instead
pub fn date(&self) -> Date<Tz>
Use date_naive() instead
Retrieves the date component with an associated timezone.
Unless you are immediately planning on turning this into a DateTime
with the same timezone you should use the date_naive method.
NaiveDate is a more well-defined type, and has more traits implemented on it,
so should be preferred to Date any time you truly want to operate on dates.
Panics
DateTime internally stores the date and time in UTC with a NaiveDateTime. This
method will panic if the offset from UTC would push the local date outside of the
representable range of a Date.
Sourcepub fn date_naive(&self) -> NaiveDate
pub fn date_naive(&self) -> NaiveDate
Retrieves the date component.
Panics
DateTime internally stores the date and time in UTC with a NaiveDateTime. This
method will panic if the offset from UTC would push the local date outside of the
representable range of a NaiveDate.
Example
use chrono::prelude::*;
let date: DateTime<Utc> = Utc.with_ymd_and_hms(2020, 1, 1, 0, 0, 0).unwrap();
let other: DateTime<FixedOffset> =
FixedOffset::east_opt(23).unwrap().with_ymd_and_hms(2020, 1, 1, 0, 0, 0).unwrap();
assert_eq!(date.date_naive(), other.date_naive());Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Returns the number of non-leap seconds since January 1, 1970 0:00:00 UTC (aka “UNIX timestamp”).
The reverse operation of creating a DateTime from a timestamp can be performed
using from_timestamp or TimeZone::timestamp_opt.
use chrono::{DateTime, TimeZone, Utc};
let dt: DateTime<Utc> = Utc.with_ymd_and_hms(2015, 5, 15, 0, 0, 0).unwrap();
assert_eq!(dt.timestamp(), 1431648000);
assert_eq!(DateTime::from_timestamp(dt.timestamp(), dt.timestamp_subsec_nanos()).unwrap(), dt);Sourcepub fn timestamp_millis(&self) -> i64
pub fn timestamp_millis(&self) -> i64
Returns the number of non-leap-milliseconds since January 1, 1970 UTC.
Example
use chrono::{NaiveDate, Utc};
let dt = NaiveDate::from_ymd_opt(1970, 1, 1)
.unwrap()
.and_hms_milli_opt(0, 0, 1, 444)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_millis(), 1_444);
let dt = NaiveDate::from_ymd_opt(2001, 9, 9)
.unwrap()
.and_hms_milli_opt(1, 46, 40, 555)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_millis(), 1_000_000_000_555);Sourcepub fn timestamp_micros(&self) -> i64
pub fn timestamp_micros(&self) -> i64
Returns the number of non-leap-microseconds since January 1, 1970 UTC.
Example
use chrono::{NaiveDate, Utc};
let dt = NaiveDate::from_ymd_opt(1970, 1, 1)
.unwrap()
.and_hms_micro_opt(0, 0, 1, 444)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_micros(), 1_000_444);
let dt = NaiveDate::from_ymd_opt(2001, 9, 9)
.unwrap()
.and_hms_micro_opt(1, 46, 40, 555)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_micros(), 1_000_000_000_000_555);Sourcepub fn timestamp_nanos(&self) -> i64
👎Deprecated since 0.4.31: use timestamp_nanos_opt() instead
pub fn timestamp_nanos(&self) -> i64
use timestamp_nanos_opt() instead
Returns the number of non-leap-nanoseconds since January 1, 1970 UTC.
Panics
An i64 with nanosecond precision can span a range of ~584 years. This function panics on
an out of range DateTime.
The dates that can be represented as nanoseconds are between 1677-09-21T00:12:43.145224192 and 2262-04-11T23:47:16.854775807.
Sourcepub fn timestamp_nanos_opt(&self) -> Option<i64>
pub fn timestamp_nanos_opt(&self) -> Option<i64>
Returns the number of non-leap-nanoseconds since January 1, 1970 UTC.
Errors
An i64 with nanosecond precision can span a range of ~584 years. This function returns
None on an out of range DateTime.
The dates that can be represented as nanoseconds are between 1677-09-21T00:12:43.145224192 and 2262-04-11T23:47:16.854775807.
Example
use chrono::{NaiveDate, Utc};
let dt = NaiveDate::from_ymd_opt(1970, 1, 1)
.unwrap()
.and_hms_nano_opt(0, 0, 1, 444)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(1_000_000_444));
let dt = NaiveDate::from_ymd_opt(2001, 9, 9)
.unwrap()
.and_hms_nano_opt(1, 46, 40, 555)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(1_000_000_000_000_000_555));
let dt = NaiveDate::from_ymd_opt(1677, 9, 21)
.unwrap()
.and_hms_nano_opt(0, 12, 43, 145_224_192)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(-9_223_372_036_854_775_808));
let dt = NaiveDate::from_ymd_opt(2262, 4, 11)
.unwrap()
.and_hms_nano_opt(23, 47, 16, 854_775_807)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), Some(9_223_372_036_854_775_807));
let dt = NaiveDate::from_ymd_opt(1677, 9, 21)
.unwrap()
.and_hms_nano_opt(0, 12, 43, 145_224_191)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), None);
let dt = NaiveDate::from_ymd_opt(2262, 4, 11)
.unwrap()
.and_hms_nano_opt(23, 47, 16, 854_775_808)
.unwrap()
.and_local_timezone(Utc)
.unwrap();
assert_eq!(dt.timestamp_nanos_opt(), None);Sourcepub fn timestamp_subsec_millis(&self) -> u32
pub fn timestamp_subsec_millis(&self) -> u32
Returns the number of milliseconds since the last second boundary.
In event of a leap second this may exceed 999.
Sourcepub fn timestamp_subsec_micros(&self) -> u32
pub fn timestamp_subsec_micros(&self) -> u32
Returns the number of microseconds since the last second boundary.
In event of a leap second this may exceed 999,999.
Sourcepub fn timestamp_subsec_nanos(&self) -> u32
pub fn timestamp_subsec_nanos(&self) -> u32
Returns the number of nanoseconds since the last second boundary
In event of a leap second this may exceed 999,999,999.
Sourcepub fn with_timezone<Tz2>(&self, tz: &Tz2) -> DateTime<Tz2>where
Tz2: TimeZone,
pub fn with_timezone<Tz2>(&self, tz: &Tz2) -> DateTime<Tz2>where
Tz2: TimeZone,
Changes the associated time zone.
The returned DateTime references the same instant of time from the perspective of the
provided time zone.
Sourcepub fn fixed_offset(&self) -> DateTime<FixedOffset>
pub fn fixed_offset(&self) -> DateTime<FixedOffset>
Fix the offset from UTC to its current value, dropping the associated timezone information.
This is useful for converting a generic DateTime<Tz: Timezone> to DateTime<FixedOffset>.
Sourcepub fn to_utc(&self) -> DateTime<Utc>
pub fn to_utc(&self) -> DateTime<Utc>
Turn this DateTime into a DateTime<Utc>, dropping the offset and associated timezone
information.
Sourcepub fn checked_add_signed(self, rhs: TimeDelta) -> Option<DateTime<Tz>>
pub fn checked_add_signed(self, rhs: TimeDelta) -> Option<DateTime<Tz>>
Adds given TimeDelta to the current date and time.
Errors
Returns None if the resulting date would be out of range.
Sourcepub fn checked_add_months(self, months: Months) -> Option<DateTime<Tz>>
pub fn checked_add_months(self, months: Months) -> Option<DateTime<Tz>>
Adds given Months to the current date and time.
Uses the last day of the month if the day does not exist in the resulting month.
See NaiveDate::checked_add_months for more details on behavior.
Errors
Returns None if:
- The local time at the resulting date does not exist or is ambiguous, for example during a daylight saving time transition.
- The resulting UTC datetime would be out of range.
- The resulting local datetime would be out of range (unless
monthsis zero).
Sourcepub fn checked_sub_signed(self, rhs: TimeDelta) -> Option<DateTime<Tz>>
pub fn checked_sub_signed(self, rhs: TimeDelta) -> Option<DateTime<Tz>>
Subtracts given TimeDelta from the current date and time.
Errors
Returns None if the resulting date would be out of range.
Sourcepub fn checked_sub_months(self, months: Months) -> Option<DateTime<Tz>>
pub fn checked_sub_months(self, months: Months) -> Option<DateTime<Tz>>
Subtracts given Months from the current date and time.
Uses the last day of the month if the day does not exist in the resulting month.
See NaiveDate::checked_sub_months for more details on behavior.
Errors
Returns None if:
- The local time at the resulting date does not exist or is ambiguous, for example during a daylight saving time transition.
- The resulting UTC datetime would be out of range.
- The resulting local datetime would be out of range (unless
monthsis zero).
Sourcepub fn checked_add_days(self, days: Days) -> Option<DateTime<Tz>>
pub fn checked_add_days(self, days: Days) -> Option<DateTime<Tz>>
Add a duration in Days to the date part of the DateTime.
Errors
Returns None if:
- The local time at the resulting date does not exist or is ambiguous, for example during a daylight saving time transition.
- The resulting UTC datetime would be out of range.
- The resulting local datetime would be out of range (unless
daysis zero).
Sourcepub fn checked_sub_days(self, days: Days) -> Option<DateTime<Tz>>
pub fn checked_sub_days(self, days: Days) -> Option<DateTime<Tz>>
Subtract a duration in Days from the date part of the DateTime.
Errors
Returns None if:
- The local time at the resulting date does not exist or is ambiguous, for example during a daylight saving time transition.
- The resulting UTC datetime would be out of range.
- The resulting local datetime would be out of range (unless
daysis zero).
Sourcepub fn signed_duration_since<Tz2>(
self,
rhs: impl Borrow<DateTime<Tz2>>,
) -> TimeDeltawhere
Tz2: TimeZone,
pub fn signed_duration_since<Tz2>(
self,
rhs: impl Borrow<DateTime<Tz2>>,
) -> TimeDeltawhere
Tz2: TimeZone,
Subtracts another DateTime from the current date and time.
This does not overflow or underflow at all.
Sourcepub fn naive_utc(&self) -> NaiveDateTime
pub fn naive_utc(&self) -> NaiveDateTime
Returns a view to the naive UTC datetime.
Sourcepub fn naive_local(&self) -> NaiveDateTime
pub fn naive_local(&self) -> NaiveDateTime
Returns a view to the naive local datetime.
Panics
DateTime internally stores the date and time in UTC with a NaiveDateTime. This
method will panic if the offset from UTC would push the local datetime outside of the
representable range of a NaiveDateTime.
Sourcepub fn years_since(&self, base: DateTime<Tz>) -> Option<u32>
pub fn years_since(&self, base: DateTime<Tz>) -> Option<u32>
Sourcepub fn to_rfc2822(&self) -> String
pub fn to_rfc2822(&self) -> String
Returns an RFC 2822 date and time string such as Tue, 1 Jul 2003 10:52:37 +0200.
Panics
Panics if the date can not be represented in this format: the year may not be negative and can not have more than 4 digits.
Sourcepub fn to_rfc3339(&self) -> String
pub fn to_rfc3339(&self) -> String
Returns an RFC 3339 and ISO 8601 date and time string such as 1996-12-19T16:39:57-08:00.
Sourcepub fn to_rfc3339_opts(&self, secform: SecondsFormat, use_z: bool) -> String
pub fn to_rfc3339_opts(&self, secform: SecondsFormat, use_z: bool) -> String
Return an RFC 3339 and ISO 8601 date and time string with subseconds
formatted as per SecondsFormat.
If use_z is true and the timezone is UTC (offset 0), uses Z as
per Fixed::TimezoneOffsetColonZ. If use_z is false, uses
Fixed::TimezoneOffsetColon
Examples
let dt = NaiveDate::from_ymd_opt(2018, 1, 26)
.unwrap()
.and_hms_micro_opt(18, 30, 9, 453_829)
.unwrap()
.and_utc();
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Millis, false), "2018-01-26T18:30:09.453+00:00");
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Millis, true), "2018-01-26T18:30:09.453Z");
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Secs, true), "2018-01-26T18:30:09Z");
let pst = FixedOffset::east_opt(8 * 60 * 60).unwrap();
let dt = pst
.from_local_datetime(
&NaiveDate::from_ymd_opt(2018, 1, 26)
.unwrap()
.and_hms_micro_opt(10, 30, 9, 453_829)
.unwrap(),
)
.unwrap();
assert_eq!(dt.to_rfc3339_opts(SecondsFormat::Secs, true), "2018-01-26T10:30:09+08:00");Sourcepub fn with_time(&self, time: NaiveTime) -> LocalResult<DateTime<Tz>>
pub fn with_time(&self, time: NaiveTime) -> LocalResult<DateTime<Tz>>
Set the time to a new fixed time on the existing date.
Errors
Returns LocalResult::None if the datetime is at the edge of the representable range for a
DateTime, and with_time would push the value in UTC out of range.
Example
use chrono::{Local, NaiveTime};
let noon = NaiveTime::from_hms_opt(12, 0, 0).unwrap();
let today_noon = Local::now().with_time(noon);
let today_midnight = Local::now().with_time(NaiveTime::MIN);
assert_eq!(today_noon.single().unwrap().time(), noon);
assert_eq!(today_midnight.single().unwrap().time(), NaiveTime::MIN);Sourcepub fn format_with_items<'a, I, B>(&self, items: I) -> DelayedFormat<I>
pub fn format_with_items<'a, I, B>(&self, items: I) -> DelayedFormat<I>
Formats the combined date and time with the specified formatting items.
Sourcepub fn format<'a>(&self, fmt: &'a str) -> DelayedFormat<StrftimeItems<'a>>
pub fn format<'a>(&self, fmt: &'a str) -> DelayedFormat<StrftimeItems<'a>>
Formats the combined date and time per the specified format string.
See the crate::format::strftime module for the supported escape sequences.
Example
use chrono::prelude::*;
let date_time: DateTime<Utc> = Utc.with_ymd_and_hms(2017, 04, 02, 12, 50, 32).unwrap();
let formatted = format!("{}", date_time.format("%d/%m/%Y %H:%M"));
assert_eq!(formatted, "02/04/2017 12:50");Trait Implementations
Sourceimpl<'de, F> BorrowDecode<'de, F> for Datetime
impl<'de, F> BorrowDecode<'de, F> for Datetime
fn borrow_decode(r: &mut BorrowReader<'de>) -> Result<Self, DecodeError>
impl Copy for Datetime
Sourceimpl DeserializeRevisioned for Datetime
impl DeserializeRevisioned for Datetime
impl Eq for Datetime
Sourceimpl Ord for Datetime
impl Ord for Datetime
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialOrd for Datetime
impl PartialOrd for Datetime
Sourceimpl Revisioned for Datetime
impl Revisioned for Datetime
Sourceimpl SerializeRevisioned for Datetime
impl SerializeRevisioned for Datetime
Sourceimpl SkipCheckRevisioned for Datetime
impl SkipCheckRevisioned for Datetime
Sourceimpl SkipRevisioned for Datetime
impl SkipRevisioned for Datetime
fn skip_revisioned<R: Read>(reader: &mut R) -> Result<(), Error>
Sourcefn skip_revisioned_slice(reader: &mut SliceReader<'_>) -> Result<(), Error>
fn skip_revisioned_slice(reader: &mut SliceReader<'_>) -> Result<(), Error>
SliceReader without allocating a buffer for bulk segments. Read moreimpl StructuralPartialEq for Datetime
Sourceimpl WalkRevisioned for Datetime
impl WalkRevisioned for Datetime
Sourcetype Walker<'r, R: BorrowedReader + 'r> = DatetimeWalker<'r, R>
type Walker<'r, R: BorrowedReader + 'r> = DatetimeWalker<'r, R>
walk_revisioned. Read moreSourcefn walk_revisioned<'r, R: BorrowedReader>(
reader: &'r mut R,
) -> Result<Self::Walker<'r, R>, Error>
fn walk_revisioned<'r, R: BorrowedReader>( reader: &'r mut R, ) -> Result<Self::Walker<'r, R>, Error>