pub struct File {
pub bucket: String,
pub key: String,
}Fields
bucket: Stringkey: StringImplementations
Sourceimpl File
impl File
Sourcepub fn walk_revisioned_field_names(
wire_revision: u16,
) -> &'static [&'static str]
pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]
Field names at the given wire revision in declaration order.
Returns an empty slice if the revision is unknown. Generated
by the revisioned derive.