pub struct Range {
pub start: Bound<Value>,
pub end: Bound<Value>,
}Expand description
A range of surrealql values,
Can be any kind of values, “a”..1 is allowed.
Fields
start: Bound<Value>end: Bound<Value>Implementations
Sourceimpl Range
impl Range
Sourcepub fn walk_revisioned_field_names(
wire_revision: u16,
) -> &'static [&'static str]
pub fn walk_revisioned_field_names( wire_revision: u16, ) -> &'static [&'static str]
Field names at the given wire revision in declaration order.
Returns an empty slice if the revision is unknown. Generated
by the revisioned derive.
Sourceimpl Range
impl Range
pub fn can_coerce_to_typed<T: Coerce>(&self) -> bool
pub fn coerce_to_typed<T: Coerce + HasKind>( self, ) -> Result<TypedRange<T>, CoerceError>
pub fn into_literal(self) -> Expr